[java-identity-provider] branch main updated: Rename package for consistency.

Scott Cantor cantor.2 at osu.edu
Tue Feb 14 15:22:17 UTC 2023


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch main
in repository java-identity-provider.

View the commit online:
http://git.shibboleth.net/view/?p=java-identity-provider.git;a=commit;h=3e0ac0bc005d121ab170816a9af62404e039e0cd

The following commit(s) were added to refs/heads/main by this push:
     new 3e0ac0bc0 Rename package for consistency.
3e0ac0bc0 is described below

commit 3e0ac0bc005d121ab170816a9af62404e039e0cd
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Tue Feb 14 10:22:13 2023 -0500

    Rename package for consistency.
---
 .../authn/proxy/impl/DiscoveryProfileRequestFunction.java    |  4 ++--
 .../net/shibboleth/idp/conf/relying-party-system.xml         |  2 +-
 .../net/shibboleth/idp/flows/saml/saml-abstract-beans.xml    |  2 +-
 .../java/net/shibboleth/idp/test/flows/SetupForResolver.java |  2 +-
 .../idp/test/flows/c14n/actions/SetupForSAML1C14N.java       |  2 +-
 .../idp/test/flows/c14n/actions/SetupForSAML2C14N.java       |  2 +-
 .../main/java/net/shibboleth/idp/profile/IdPEventIds.java    |  2 +-
 .../idp/profile/config/logic/DetailedErrorsPredicate.java    |  4 ++--
 .../java/net/shibboleth/idp/profile/config/package-info.java |  2 +-
 .../profile/context/navigate/ResponderIdLookupFunction.java  |  6 +++---
 .../relyingparty/RelyingPartyConfiguration.java              |  2 +-
 .../idp/{ => profile}/relyingparty/package-info.java         |  2 +-
 idp-profile-api/src/test/resources/logback-test.xml          |  2 +-
 .../idp/relyingparty/impl/CriteriaSelfEntityIDResolver.java  |  4 ++--
 .../profile/impl/SelectRelyingPartyConfigurationTest.java    |  6 +++---
 idp-profile-impl/src/test/resources/logback-test.xml         |  2 +-
 .../profile/logic/DefaultNameIdentifierFormatStrategy.java   |  3 +--
 .../relyingparty/impl/RelyingPartyConfigurationSupport.java  |  2 +-
 .../shibboleth/idp/saml/relyingparty/impl/package-info.java  |  2 +-
 .../profile/impl/AddAuthenticationStatementToAssertion.java  |  2 +-
 .../saml2/profile/impl/AddAuthnStatementToAssertion.java     |  2 +-
 .../impl/tests/RelyingPartyConfigurationResolverTest.java    | 12 ++++++------
 .../AttributeSourcedSAML1NameIdentifierGeneratorTest.java    |  4 ++--
 .../impl/AttributeSourcedSAML2NameIDGeneratorTest.java       |  4 ++--
 .../CryptoTransientSAML1NameIdentifierGeneratorTest.java     |  2 +-
 .../nameid/impl/CryptoTransientSAML2NameIDGeneratorTest.java |  2 +-
 .../StoredTransientSAML1NameIdentifierGeneratorTest.java     |  2 +-
 .../nameid/impl/StoredTransientSAML2NameIDGeneratorTest.java |  2 +-
 .../idp/saml/saml2/profile/impl/AddAuthnRequestTest.java     |  2 +-
 .../idp/profile/testing/RequestContextBuilder.java           |  3 +--
 .../saml1/profile/testing/SAML1ActionTestingSupport.java     |  2 +-
 .../saml2/profile/testing/SAML2ActionTestingSupport.java     |  2 +-
 .../saml/saml1/profile/testing/SAML1ActionSupportTest.java   |  4 ++--
 .../saml/saml2/profile/testing/SAML2ActionSupportTest.java   |  4 ++--
 34 files changed, 50 insertions(+), 52 deletions(-)

diff --git a/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/proxy/impl/DiscoveryProfileRequestFunction.java b/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/proxy/impl/DiscoveryProfileRequestFunction.java
index a62749f5c..eeff778fe 100644
--- a/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/proxy/impl/DiscoveryProfileRequestFunction.java
+++ b/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/proxy/impl/DiscoveryProfileRequestFunction.java
@@ -115,9 +115,9 @@ public class DiscoveryProfileRequestFunction extends AbstractInitializableCompon
         Constraint.isNotEmpty(baseURL, "Discovery URL cannot be null or empty");
 
         final RelyingPartyConfiguration rpConfig = rpCtx.getConfiguration();
-        Constraint.isTrue(rpConfig instanceof net.shibboleth.idp.relyingparty.RelyingPartyConfiguration,
+        Constraint.isTrue(rpConfig instanceof net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration,
                 "RelyingPartyConfiguration was not of expected subclass");
-        final String entityID = ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) rpConfig).getResponderId(
+        final String entityID = ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) rpConfig).getResponderId(
                 input.getSecond());
 
         final StringBuilder builder = new StringBuilder(baseURL);
diff --git a/idp-conf-impl/src/main/resources/net/shibboleth/idp/conf/relying-party-system.xml b/idp-conf-impl/src/main/resources/net/shibboleth/idp/conf/relying-party-system.xml
index 1ce4f0207..e1698bddb 100644
--- a/idp-conf-impl/src/main/resources/net/shibboleth/idp/conf/relying-party-system.xml
+++ b/idp-conf-impl/src/main/resources/net/shibboleth/idp/conf/relying-party-system.xml
@@ -38,7 +38,7 @@
     </bean>
 
     <!-- Parent bean for generic RelyingParty overrides that establishes defaults. -->
-    <bean id="RelyingParty" abstract="true" class="net.shibboleth.idp.relyingparty.RelyingPartyConfiguration"
+    <bean id="RelyingParty" abstract="true" class="net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration"
         p:responderId="#{getObject('entityID')}"
         p:detailedErrorsPredicate="%{idp.errors.detailed:false}" />
 
diff --git a/idp-conf-impl/src/main/resources/net/shibboleth/idp/flows/saml/saml-abstract-beans.xml b/idp-conf-impl/src/main/resources/net/shibboleth/idp/flows/saml/saml-abstract-beans.xml
index 407096c98..d57a27d1e 100644
--- a/idp-conf-impl/src/main/resources/net/shibboleth/idp/flows/saml/saml-abstract-beans.xml
+++ b/idp-conf-impl/src/main/resources/net/shibboleth/idp/flows/saml/saml-abstract-beans.xml
@@ -345,7 +345,7 @@
     <!-- Non-ProfileRequestContext oriented beans, for example for us in SOAPClient. -->        
     
     <bean id="ArtifactSupport.SelfEntityIDResolver" 
-        class="net.shibboleth.idp.relyingparty.impl.CriteriaSelfEntityIDResolver"
+        class="net.shibboleth.idp.profile.relyingparty.impl.CriteriaSelfEntityIDResolver"
         p:relyingPartyConfigurationResolver-ref="shibboleth.RelyingPartyResolverService" />
 
 </beans>
diff --git a/idp-conf/src/test/java/net/shibboleth/idp/test/flows/SetupForResolver.java b/idp-conf/src/test/java/net/shibboleth/idp/test/flows/SetupForResolver.java
index 133982721..53705091e 100644
--- a/idp-conf/src/test/java/net/shibboleth/idp/test/flows/SetupForResolver.java
+++ b/idp-conf/src/test/java/net/shibboleth/idp/test/flows/SetupForResolver.java
@@ -22,7 +22,7 @@ import javax.annotation.Nonnull;
 import net.shibboleth.idp.authn.context.SubjectContext;
 import net.shibboleth.idp.profile.AbstractProfileAction;
 import net.shibboleth.idp.profile.IdPEventIds;
-import net.shibboleth.idp.relyingparty.RelyingPartyConfiguration;
+import net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.profile.context.RelyingPartyContext;
 import net.shibboleth.shared.component.ComponentInitializationException;
 
diff --git a/idp-conf/src/test/java/net/shibboleth/idp/test/flows/c14n/actions/SetupForSAML1C14N.java b/idp-conf/src/test/java/net/shibboleth/idp/test/flows/c14n/actions/SetupForSAML1C14N.java
index ccb6409d0..b0e376cfc 100644
--- a/idp-conf/src/test/java/net/shibboleth/idp/test/flows/c14n/actions/SetupForSAML1C14N.java
+++ b/idp-conf/src/test/java/net/shibboleth/idp/test/flows/c14n/actions/SetupForSAML1C14N.java
@@ -37,7 +37,7 @@ import net.shibboleth.idp.attribute.StringAttributeValue;
 import net.shibboleth.idp.attribute.context.AttributeContext;
 import net.shibboleth.idp.authn.context.SubjectCanonicalizationContext;
 import net.shibboleth.idp.profile.AbstractProfileAction;
-import net.shibboleth.idp.relyingparty.RelyingPartyConfiguration;
+import net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.idp.saml.authn.principal.NameIdentifierPrincipal;
 import net.shibboleth.idp.saml.nameid.impl.TransientSAML1NameIdentifierGenerator;
 import net.shibboleth.idp.saml.xml.SAMLConstants;
diff --git a/idp-conf/src/test/java/net/shibboleth/idp/test/flows/c14n/actions/SetupForSAML2C14N.java b/idp-conf/src/test/java/net/shibboleth/idp/test/flows/c14n/actions/SetupForSAML2C14N.java
index 36a1de5d9..248e0c537 100644
--- a/idp-conf/src/test/java/net/shibboleth/idp/test/flows/c14n/actions/SetupForSAML2C14N.java
+++ b/idp-conf/src/test/java/net/shibboleth/idp/test/flows/c14n/actions/SetupForSAML2C14N.java
@@ -38,7 +38,7 @@ import net.shibboleth.idp.attribute.StringAttributeValue;
 import net.shibboleth.idp.attribute.context.AttributeContext;
 import net.shibboleth.idp.authn.context.SubjectCanonicalizationContext;
 import net.shibboleth.idp.profile.AbstractProfileAction;
-import net.shibboleth.idp.relyingparty.RelyingPartyConfiguration;
+import net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.idp.saml.authn.principal.NameIDPrincipal;
 import net.shibboleth.idp.saml.nameid.impl.TransientSAML2NameIDGenerator;
 import net.shibboleth.profile.context.RelyingPartyContext;
diff --git a/idp-profile-api/src/main/java/net/shibboleth/idp/profile/IdPEventIds.java b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/IdPEventIds.java
index e2731611f..1eeb2bf96 100644
--- a/idp-profile-api/src/main/java/net/shibboleth/idp/profile/IdPEventIds.java
+++ b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/IdPEventIds.java
@@ -19,7 +19,7 @@ package net.shibboleth.idp.profile;
 
 import javax.annotation.Nonnull;
 
-import net.shibboleth.idp.relyingparty.RelyingPartyConfiguration;
+import net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.profile.config.ProfileConfiguration;
 import net.shibboleth.profile.context.RelyingPartyContext;
 import net.shibboleth.shared.annotation.constraint.NotEmpty;
diff --git a/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/logic/DetailedErrorsPredicate.java b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/logic/DetailedErrorsPredicate.java
index e8717e772..85a4ab569 100644
--- a/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/logic/DetailedErrorsPredicate.java
+++ b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/logic/DetailedErrorsPredicate.java
@@ -36,8 +36,8 @@ public class DetailedErrorsPredicate extends AbstractRelyingPartyPredicate {
             final RelyingPartyContext rpc = getRelyingPartyContextLookupStrategy().apply(input);
             if (rpc != null) {
                 final RelyingPartyConfiguration config = rpc.getConfiguration();
-                if (config instanceof net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) {
-                    return ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) config).isDetailedErrors(input);
+                if (config instanceof net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) {
+                    return ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) config).isDetailedErrors(input);
                 }
             }
         }
diff --git a/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/package-info.java b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/package-info.java
index 2f746bd40..76cfae69b 100644
--- a/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/package-info.java
+++ b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/package-info.java
@@ -18,7 +18,7 @@
 /** 
  * Classes pertaining to request-time profile configuration options.   The classes representing the request-time 
  * configuration options for a given profile generally hang off of a 
- * {@link net.shibboleth.idp.relyingparty.RelyingPartyConfiguration} but some profile handlers may do this differently.
+ * {@link net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration} but some profile handlers may do this differently.
  */
 
 package net.shibboleth.idp.profile.config;
\ No newline at end of file
diff --git a/idp-profile-api/src/main/java/net/shibboleth/idp/relyingparty/RelyingPartyConfiguration.java b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/relyingparty/RelyingPartyConfiguration.java
similarity index 98%
rename from idp-profile-api/src/main/java/net/shibboleth/idp/relyingparty/RelyingPartyConfiguration.java
rename to idp-profile-api/src/main/java/net/shibboleth/idp/profile/relyingparty/RelyingPartyConfiguration.java
index 274bfbbb2..67bacd433 100644
--- a/idp-profile-api/src/main/java/net/shibboleth/idp/relyingparty/RelyingPartyConfiguration.java
+++ b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/relyingparty/RelyingPartyConfiguration.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package net.shibboleth.idp.relyingparty;
+package net.shibboleth.idp.profile.relyingparty;
 
 import java.util.function.Function;
 import java.util.function.Predicate;
diff --git a/idp-profile-api/src/main/java/net/shibboleth/idp/relyingparty/package-info.java b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/relyingparty/package-info.java
similarity index 95%
rename from idp-profile-api/src/main/java/net/shibboleth/idp/relyingparty/package-info.java
rename to idp-profile-api/src/main/java/net/shibboleth/idp/profile/relyingparty/package-info.java
index 0582204be..531301994 100644
--- a/idp-profile-api/src/main/java/net/shibboleth/idp/relyingparty/package-info.java
+++ b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/relyingparty/package-info.java
@@ -17,4 +17,4 @@
 
 /** APIs for retrieving the per-relying party configuration for a given profile request. */
 
-package net.shibboleth.idp.relyingparty;
\ No newline at end of file
+package net.shibboleth.idp.profile.relyingparty;
\ No newline at end of file
diff --git a/idp-profile-api/src/test/resources/logback-test.xml b/idp-profile-api/src/test/resources/logback-test.xml
index 48836d91a..9fda610b8 100644
--- a/idp-profile-api/src/test/resources/logback-test.xml
+++ b/idp-profile-api/src/test/resources/logback-test.xml
@@ -2,7 +2,7 @@
 <configuration>
 
     <logger name="net.shibboleth.idp.profile" level="DEBUG"/>
-    <logger name="net.shibboleth.idp.relyingparty" level="DEBUG"/>
+    <logger name="net.shibboleth.idp.profile.relyingparty" level="DEBUG"/>
 
     <appender name="CONSOLE" class="ch.qos.logback.core.ConsoleAppender">
         <encoder class="ch.qos.logback.classic.encoder.PatternLayoutEncoder">
diff --git a/idp-profile-impl/src/main/java/net/shibboleth/idp/relyingparty/impl/CriteriaSelfEntityIDResolver.java b/idp-profile-impl/src/main/java/net/shibboleth/idp/relyingparty/impl/CriteriaSelfEntityIDResolver.java
index 027e2ca52..59f46a350 100644
--- a/idp-profile-impl/src/main/java/net/shibboleth/idp/relyingparty/impl/CriteriaSelfEntityIDResolver.java
+++ b/idp-profile-impl/src/main/java/net/shibboleth/idp/relyingparty/impl/CriteriaSelfEntityIDResolver.java
@@ -123,8 +123,8 @@ public class CriteriaSelfEntityIDResolver extends AbstractIdentifiedInitializabl
         try {
             final RelyingPartyConfiguration rpc =
                     rpcResolver.getServiceableComponent().getComponent().resolveSingle(prcSet);
-            if (rpc instanceof net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) {
-                return ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) rpc).getResponderId(prc);
+            if (rpc instanceof net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) {
+                return ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) rpc).getResponderId(prc);
             }
         } catch (final ServiceException e) {
             log.error("RelyingPartyConfiguration resolver unvailable", e);
diff --git a/idp-profile-impl/src/test/java/net/shibboleth/idp/profile/impl/SelectRelyingPartyConfigurationTest.java b/idp-profile-impl/src/test/java/net/shibboleth/idp/profile/impl/SelectRelyingPartyConfigurationTest.java
index 258595e01..8f41942f3 100644
--- a/idp-profile-impl/src/test/java/net/shibboleth/idp/profile/impl/SelectRelyingPartyConfigurationTest.java
+++ b/idp-profile-impl/src/test/java/net/shibboleth/idp/profile/impl/SelectRelyingPartyConfigurationTest.java
@@ -107,7 +107,7 @@ public class SelectRelyingPartyConfigurationTest {
         final ProfileRequestContext prc = new WebflowRequestContextProfileRequestContextLookup().apply(src);
         prc.getSubcontext(RelyingPartyContext.class).setConfiguration(null);
 
-        final var config = new net.shibboleth.idp.relyingparty.RelyingPartyConfiguration();
+        final var config = new net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration();
         config.setId("foo");
         config.setResponderId("http://idp.example.org");
         config.setDetailedErrors(true);
@@ -132,7 +132,7 @@ public class SelectRelyingPartyConfigurationTest {
         final ProfileRequestContext prc = new WebflowRequestContextProfileRequestContextLookup().apply(src);
         prc.getSubcontext(RelyingPartyContext.class).setConfiguration(null);
 
-        final var config = new net.shibboleth.idp.relyingparty.RelyingPartyConfiguration();
+        final var config = new net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration();
         config.setId("foo");
         config.setResponderId("http://idp.example.org");
         config.setDetailedErrors(true);
@@ -149,7 +149,7 @@ public class SelectRelyingPartyConfigurationTest {
         final RelyingPartyConfiguration resolvedConfig =
                 (RelyingPartyConfiguration) prc.getSubcontext(RelyingPartyContext.class).getConfiguration();
         Assert.assertEquals(resolvedConfig.getId(), config.getId());
-        Assert.assertEquals(((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) resolvedConfig).getResponderId(prc),
+        Assert.assertEquals(((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) resolvedConfig).getResponderId(prc),
                 config.getResponderId(prc));
         Assert.assertEquals(resolvedConfig.getProfileConfigurations(prc), config.getProfileConfigurations(prc));
     }
diff --git a/idp-profile-impl/src/test/resources/logback-test.xml b/idp-profile-impl/src/test/resources/logback-test.xml
index 48836d91a..9fda610b8 100644
--- a/idp-profile-impl/src/test/resources/logback-test.xml
+++ b/idp-profile-impl/src/test/resources/logback-test.xml
@@ -2,7 +2,7 @@
 <configuration>
 
     <logger name="net.shibboleth.idp.profile" level="DEBUG"/>
-    <logger name="net.shibboleth.idp.relyingparty" level="DEBUG"/>
+    <logger name="net.shibboleth.idp.profile.relyingparty" level="DEBUG"/>
 
     <appender name="CONSOLE" class="ch.qos.logback.core.ConsoleAppender">
         <encoder class="ch.qos.logback.classic.encoder.PatternLayoutEncoder">
diff --git a/idp-saml-api/src/main/java/net/shibboleth/idp/saml/profile/logic/DefaultNameIdentifierFormatStrategy.java b/idp-saml-api/src/main/java/net/shibboleth/idp/saml/profile/logic/DefaultNameIdentifierFormatStrategy.java
index 943aa6175..7149721a0 100644
--- a/idp-saml-api/src/main/java/net/shibboleth/idp/saml/profile/logic/DefaultNameIdentifierFormatStrategy.java
+++ b/idp-saml-api/src/main/java/net/shibboleth/idp/saml/profile/logic/DefaultNameIdentifierFormatStrategy.java
@@ -81,8 +81,7 @@ public class DefaultNameIdentifierFormatStrategy extends MetadataNameIdentifierF
     }
     
     /**
-     * Set the profile configuration ID to locate in the
-     * {@link net.shibboleth.idp.relyingparty.RelyingPartyConfiguration} for the purposes of
+     * Set the profile configuration ID to locate in the {@link RelyingPartyConfiguration} for the purposes of
      * establishing format precedence rules.
      * 
      * <p>By default/without one set, the strategy is to use the configuration object populated in the
diff --git a/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/relyingparty/impl/RelyingPartyConfigurationSupport.java b/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/relyingparty/impl/RelyingPartyConfigurationSupport.java
index 555ba3a41..5bf3568a4 100644
--- a/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/relyingparty/impl/RelyingPartyConfigurationSupport.java
+++ b/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/relyingparty/impl/RelyingPartyConfigurationSupport.java
@@ -31,7 +31,7 @@ import org.opensaml.saml.metadata.resolver.MetadataResolver;
 import org.opensaml.saml.saml2.metadata.EntityDescriptor;
 
 import net.shibboleth.idp.profile.logic.RelyingPartyIdPredicate;
-import net.shibboleth.idp.relyingparty.RelyingPartyConfiguration;
+import net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.idp.saml.profile.context.navigate.SAMLMetadataContextLookupFunction;
 import net.shibboleth.idp.saml.profile.logic.MappedEntityAttributesPredicate;
 import net.shibboleth.shared.annotation.constraint.NonnullElements;
diff --git a/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/relyingparty/impl/package-info.java b/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/relyingparty/impl/package-info.java
index 78ccd25ab..3af1edb52 100644
--- a/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/relyingparty/impl/package-info.java
+++ b/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/relyingparty/impl/package-info.java
@@ -16,7 +16,7 @@
  */
 
 /**
- * Helpers for constructing {@link net.shibboleth.idp.relyingparty.RelyingPartyConfiguration} objects
+ * Helpers for constructing {@link net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration} objects
  * with SAML-specific predicates.
  */
 
diff --git a/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/saml1/profile/impl/AddAuthenticationStatementToAssertion.java b/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/saml1/profile/impl/AddAuthenticationStatementToAssertion.java
index 9be23addd..15034aea1 100644
--- a/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/saml1/profile/impl/AddAuthenticationStatementToAssertion.java
+++ b/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/saml1/profile/impl/AddAuthenticationStatementToAssertion.java
@@ -55,7 +55,7 @@ import net.shibboleth.shared.security.IdentifierGenerationStrategy;
  * 
  * <p>A constructed {@link Assertion} will have its ID, IssueInstant, Issuer, and Version properties set.
  * The issuer is based on
- * {@link net.shibboleth.idp.relyingparty.RelyingPartyConfiguration#getResponderId(ProfileRequestContext)}.</p>
+ * {@link net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration#getResponderId(ProfileRequestContext)}.</p>
  * 
  * <p>The {@link AuthenticationStatement} will have its authentication instant set, based on
  * {@link net.shibboleth.idp.authn.AuthenticationResult#getAuthenticationInstant()}
diff --git a/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/saml2/profile/impl/AddAuthnStatementToAssertion.java b/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/saml2/profile/impl/AddAuthnStatementToAssertion.java
index 1952e7bc2..a0171081c 100644
--- a/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/saml2/profile/impl/AddAuthnStatementToAssertion.java
+++ b/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/saml2/profile/impl/AddAuthnStatementToAssertion.java
@@ -65,7 +65,7 @@ import net.shibboleth.shared.primitive.LoggerFactory;
  * 
  * <p>A constructed {@link Assertion} will have its ID, IssueInstant, Issuer, and Version properties set.
  * The issuer is based on
- * {@link net.shibboleth.idp.relyingparty.RelyingPartyConfiguration#getResponderId(ProfileRequestContext)}.</p>
+ * {@link net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration#getResponderId(ProfileRequestContext)}.</p>
  * 
  * <p>The {@link AuthnStatement} will have its authentication instant set, based on
  * {@link net.shibboleth.idp.authn.AuthenticationResult#getAuthenticationInstant()}
diff --git a/idp-saml-impl/src/test/java/net/shibboleth/idp/relyingparty/impl/tests/RelyingPartyConfigurationResolverTest.java b/idp-saml-impl/src/test/java/net/shibboleth/idp/relyingparty/impl/tests/RelyingPartyConfigurationResolverTest.java
index 9c0e3de24..bf7df289f 100644
--- a/idp-saml-impl/src/test/java/net/shibboleth/idp/relyingparty/impl/tests/RelyingPartyConfigurationResolverTest.java
+++ b/idp-saml-impl/src/test/java/net/shibboleth/idp/relyingparty/impl/tests/RelyingPartyConfigurationResolverTest.java
@@ -56,23 +56,23 @@ import net.shibboleth.shared.resolver.ResolverException;
 @SuppressWarnings("javadoc")
 public class RelyingPartyConfigurationResolverTest extends XMLObjectBaseTestCase {
     
-    private net.shibboleth.idp.relyingparty.RelyingPartyConfiguration anonRP, defaultRP; 
+    private net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration anonRP, defaultRP; 
     
-    private net.shibboleth.idp.relyingparty.RelyingPartyConfiguration oneByName, twoByName, threeByName;
-    private net.shibboleth.idp.relyingparty.RelyingPartyConfiguration oneByGroup, twoByGroup;
-    private net.shibboleth.idp.relyingparty.RelyingPartyConfiguration oneByTag, twoByTag;
+    private net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration oneByName, twoByName, threeByName;
+    private net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration oneByGroup, twoByGroup;
+    private net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration oneByTag, twoByTag;
     
     private DefaultRelyingPartyConfigurationResolver resolver;
         
     @BeforeMethod
     public void setup() throws ComponentInitializationException {
-        anonRP = new net.shibboleth.idp.relyingparty.RelyingPartyConfiguration();
+        anonRP = new net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration();
         anonRP.setId("anonRPId");
         anonRP.setResponderId("anonRPResp");
         anonRP.setDetailedErrors(true);
         anonRP.initialize();
         
-        defaultRP = new net.shibboleth.idp.relyingparty.RelyingPartyConfiguration();
+        defaultRP = new net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration();
         defaultRP.setId("defaultRPId");
         defaultRP.setResponderId("defaultRPResp");
         defaultRP.setDetailedErrors(true);
diff --git a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/AttributeSourcedSAML1NameIdentifierGeneratorTest.java b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/AttributeSourcedSAML1NameIdentifierGeneratorTest.java
index 1064e49f7..25c4a4645 100644
--- a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/AttributeSourcedSAML1NameIdentifierGeneratorTest.java
+++ b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/AttributeSourcedSAML1NameIdentifierGeneratorTest.java
@@ -188,7 +188,7 @@ public class AttributeSourcedSAML1NameIdentifierGeneratorTest extends OpenSAMLIn
         Assert.assertEquals(outputNameId.getValue(), NAME_1);
         Assert.assertEquals(outputNameId.getFormat(), NameIdentifier.X509_SUBJECT);
         Assert.assertEquals(outputNameId.getNameQualifier(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) prc.getSubcontext(RelyingPartyContext.class).getConfiguration()).getResponderId(prc));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) prc.getSubcontext(RelyingPartyContext.class).getConfiguration()).getResponderId(prc));
     }
 
     @Test public void testScopeValued() throws Exception {
@@ -205,6 +205,6 @@ public class AttributeSourcedSAML1NameIdentifierGeneratorTest extends OpenSAMLIn
         Assert.assertEquals(outputNameId.getValue(), NAME_1 + '@' + QUALIFIER);
         Assert.assertEquals(outputNameId.getFormat(), NameIdentifier.X509_SUBJECT);
         Assert.assertEquals(outputNameId.getNameQualifier(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) prc.getSubcontext(RelyingPartyContext.class).getConfiguration()).getResponderId(prc));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) prc.getSubcontext(RelyingPartyContext.class).getConfiguration()).getResponderId(prc));
     }
 }
diff --git a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/AttributeSourcedSAML2NameIDGeneratorTest.java b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/AttributeSourcedSAML2NameIDGeneratorTest.java
index 4550491af..bb1a311b2 100644
--- a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/AttributeSourcedSAML2NameIDGeneratorTest.java
+++ b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/AttributeSourcedSAML2NameIDGeneratorTest.java
@@ -187,7 +187,7 @@ public class AttributeSourcedSAML2NameIDGeneratorTest extends OpenSAMLInitBaseTe
         Assert.assertEquals(outputNameId.getValue(), NAME_1);
         Assert.assertEquals(outputNameId.getFormat(), NameID.X509_SUBJECT);
         Assert.assertEquals(outputNameId.getNameQualifier(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) prc.getSubcontext(RelyingPartyContext.class).getConfiguration()).getResponderId(prc));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) prc.getSubcontext(RelyingPartyContext.class).getConfiguration()).getResponderId(prc));
     }
 
     @Test public void testScopeValued() throws Exception {
@@ -204,7 +204,7 @@ public class AttributeSourcedSAML2NameIDGeneratorTest extends OpenSAMLInitBaseTe
         Assert.assertEquals(outputNameId.getValue(), NAME_1 + '@' + QUALIFIER);
         Assert.assertEquals(outputNameId.getFormat(), NameID.X509_SUBJECT);
         Assert.assertEquals(outputNameId.getNameQualifier(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) prc.getSubcontext(RelyingPartyContext.class).getConfiguration()).getResponderId(prc));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) prc.getSubcontext(RelyingPartyContext.class).getConfiguration()).getResponderId(prc));
         Assert.assertEquals(outputNameId.getSPNameQualifier(),
                 prc.getSubcontext(RelyingPartyContext.class).getRelyingPartyId());
     }
diff --git a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/CryptoTransientSAML1NameIdentifierGeneratorTest.java b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/CryptoTransientSAML1NameIdentifierGeneratorTest.java
index 2a07701ef..57283e5cc 100644
--- a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/CryptoTransientSAML1NameIdentifierGeneratorTest.java
+++ b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/CryptoTransientSAML1NameIdentifierGeneratorTest.java
@@ -121,7 +121,7 @@ public class CryptoTransientSAML1NameIdentifierGeneratorTest extends OpenSAMLIni
         Assert.assertNotNull(name);
         Assert.assertEquals(name.getFormat(), generator.getFormat());
         Assert.assertEquals(name.getNameQualifier(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) rpc.getConfiguration()).getResponderId(prc));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) rpc.getConfiguration()).getResponderId(prc));
 
         final String val = name.getValue();
 
diff --git a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/CryptoTransientSAML2NameIDGeneratorTest.java b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/CryptoTransientSAML2NameIDGeneratorTest.java
index 779419ee9..98b1998d6 100644
--- a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/CryptoTransientSAML2NameIDGeneratorTest.java
+++ b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/CryptoTransientSAML2NameIDGeneratorTest.java
@@ -122,7 +122,7 @@ public class CryptoTransientSAML2NameIDGeneratorTest extends OpenSAMLInitBaseTes
         Assert.assertNotNull(name);
         Assert.assertEquals(name.getFormat(), generator.getFormat());
         Assert.assertEquals(name.getNameQualifier(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) rpc.getConfiguration()).getResponderId(prc));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) rpc.getConfiguration()).getResponderId(prc));
 
         final String val = name.getValue();
 
diff --git a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/StoredTransientSAML1NameIdentifierGeneratorTest.java b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/StoredTransientSAML1NameIdentifierGeneratorTest.java
index ce4121662..323928c25 100644
--- a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/StoredTransientSAML1NameIdentifierGeneratorTest.java
+++ b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/StoredTransientSAML1NameIdentifierGeneratorTest.java
@@ -96,7 +96,7 @@ public class StoredTransientSAML1NameIdentifierGeneratorTest extends OpenSAMLIni
         Assert.assertNotNull(name);
         Assert.assertEquals(name.getFormat(), generator.getFormat());
         Assert.assertEquals(name.getNameQualifier(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) rpc.getConfiguration()).getResponderId(prc));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) rpc.getConfiguration()).getResponderId(prc));
 
         String val = name.getValue();
 
diff --git a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/StoredTransientSAML2NameIDGeneratorTest.java b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/StoredTransientSAML2NameIDGeneratorTest.java
index 7c152b2da..5e4baf3a9 100644
--- a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/StoredTransientSAML2NameIDGeneratorTest.java
+++ b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/nameid/impl/StoredTransientSAML2NameIDGeneratorTest.java
@@ -97,7 +97,7 @@ public class StoredTransientSAML2NameIDGeneratorTest extends OpenSAMLInitBaseTes
         Assert.assertNotNull(name);
         Assert.assertEquals(name.getFormat(), generator.getFormat());
         Assert.assertEquals(name.getNameQualifier(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) rpc.getConfiguration()).getResponderId(prc));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) rpc.getConfiguration()).getResponderId(prc));
         Assert.assertEquals(name.getSPNameQualifier(), rpc.getRelyingPartyId());
 
         String val = name.getValue();
diff --git a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/saml2/profile/impl/AddAuthnRequestTest.java b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/saml2/profile/impl/AddAuthnRequestTest.java
index 1ef5953f8..0c47959df 100644
--- a/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/saml2/profile/impl/AddAuthnRequestTest.java
+++ b/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/saml2/profile/impl/AddAuthnRequestTest.java
@@ -32,9 +32,9 @@ import org.opensaml.profile.context.ProfileRequestContext;
 
 import net.shibboleth.idp.profile.context.navigate.ResponderIdLookupFunction;
 import net.shibboleth.idp.profile.context.navigate.WebflowRequestContextProfileRequestContextLookup;
+import net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.idp.profile.testing.ActionTestingSupport;
 import net.shibboleth.idp.profile.testing.RequestContextBuilder;
-import net.shibboleth.idp.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.idp.saml.authn.principal.AuthenticationMethodPrincipal;
 import net.shibboleth.idp.saml.authn.principal.AuthnContextClassRefPrincipal;
 import net.shibboleth.idp.saml.saml2.profile.config.BrowserSSOProfileConfiguration;
diff --git a/idp-testing/src/main/java/net/shibboleth/idp/profile/testing/RequestContextBuilder.java b/idp-testing/src/main/java/net/shibboleth/idp/profile/testing/RequestContextBuilder.java
index 0c65c3eff..10dbd49c0 100644
--- a/idp-testing/src/main/java/net/shibboleth/idp/profile/testing/RequestContextBuilder.java
+++ b/idp-testing/src/main/java/net/shibboleth/idp/profile/testing/RequestContextBuilder.java
@@ -31,10 +31,9 @@ import javax.annotation.Nullable;
 import jakarta.servlet.ServletContext;
 import jakarta.servlet.http.HttpServletRequest;
 import jakarta.servlet.http.HttpServletResponse;
-
+import net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.profile.config.ProfileConfiguration;
 import net.shibboleth.profile.context.RelyingPartyContext;
-import net.shibboleth.idp.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.shared.component.ComponentInitializationException;
 
 import org.opensaml.messaging.context.MessageContext;
diff --git a/idp-testing/src/main/java/net/shibboleth/idp/saml/saml1/profile/testing/SAML1ActionTestingSupport.java b/idp-testing/src/main/java/net/shibboleth/idp/saml/saml1/profile/testing/SAML1ActionTestingSupport.java
index 0b8df86f5..cbdb5d907 100644
--- a/idp-testing/src/main/java/net/shibboleth/idp/saml/saml1/profile/testing/SAML1ActionTestingSupport.java
+++ b/idp-testing/src/main/java/net/shibboleth/idp/saml/saml1/profile/testing/SAML1ActionTestingSupport.java
@@ -25,8 +25,8 @@ import javax.annotation.Nullable;
 
 import net.shibboleth.profile.config.ProfileConfiguration;
 import net.shibboleth.profile.context.RelyingPartyContext;
+import net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.idp.profile.testing.ActionTestingSupport;
-import net.shibboleth.idp.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.idp.saml.saml1.profile.config.ArtifactResolutionProfileConfiguration;
 import net.shibboleth.idp.saml.saml1.profile.config.AttributeQueryProfileConfiguration;
 import net.shibboleth.idp.saml.saml1.profile.config.BrowserSSOProfileConfiguration;
diff --git a/idp-testing/src/main/java/net/shibboleth/idp/saml/saml2/profile/testing/SAML2ActionTestingSupport.java b/idp-testing/src/main/java/net/shibboleth/idp/saml/saml2/profile/testing/SAML2ActionTestingSupport.java
index 34f0e1e34..62ba8a9f5 100644
--- a/idp-testing/src/main/java/net/shibboleth/idp/saml/saml2/profile/testing/SAML2ActionTestingSupport.java
+++ b/idp-testing/src/main/java/net/shibboleth/idp/saml/saml2/profile/testing/SAML2ActionTestingSupport.java
@@ -25,8 +25,8 @@ import javax.annotation.Nullable;
 
 import net.shibboleth.profile.config.ProfileConfiguration;
 import net.shibboleth.profile.context.RelyingPartyContext;
+import net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.idp.profile.testing.ActionTestingSupport;
-import net.shibboleth.idp.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.idp.saml.saml2.profile.config.ArtifactResolutionProfileConfiguration;
 import net.shibboleth.idp.saml.saml2.profile.config.AttributeQueryProfileConfiguration;
 import net.shibboleth.idp.saml.saml2.profile.config.BrowserSSOProfileConfiguration;
diff --git a/idp-testing/src/test/java/net/shibboleth/idp/saml/saml1/profile/testing/SAML1ActionSupportTest.java b/idp-testing/src/test/java/net/shibboleth/idp/saml/saml1/profile/testing/SAML1ActionSupportTest.java
index 6bf0d846a..c86589e9a 100644
--- a/idp-testing/src/test/java/net/shibboleth/idp/saml/saml1/profile/testing/SAML1ActionSupportTest.java
+++ b/idp-testing/src/test/java/net/shibboleth/idp/saml/saml1/profile/testing/SAML1ActionSupportTest.java
@@ -68,12 +68,12 @@ public class SAML1ActionSupportTest extends OpenSAMLInitBaseTestCase {
         Assert.assertEquals(response.getAssertions().size(), 0, "Expected zarro assertions before insert");
         final Assertion assertion = SAML1ActionSupport.addAssertionToResponse(action, response,
                 relyingPartyCtx.getProfileConfig().getSecurityConfiguration(profileRequestContext).getIdGenerator(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) relyingPartyCtx.getConfiguration()).getResponderId(profileRequestContext));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) relyingPartyCtx.getConfiguration()).getResponderId(profileRequestContext));
         Assert.assertEquals(response.getAssertions().size(), 1, "Expected but one assertion after insert");
         Assert.assertTrue(response.getAssertions().contains(assertion), "Inserted assertion should be there");
         final Assertion second = SAML1ActionSupport.addAssertionToResponse(action, response,
                 relyingPartyCtx.getProfileConfig().getSecurityConfiguration(profileRequestContext).getIdGenerator(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) relyingPartyCtx.getConfiguration()).getResponderId(profileRequestContext));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) relyingPartyCtx.getConfiguration()).getResponderId(profileRequestContext));
         Assert.assertEquals(response.getAssertions().size(), 2, "Expected two assertions after two inserts");
         Assert.assertTrue(response.getAssertions().contains(assertion), "Inserted assertion should be there");
         Assert.assertNotSame(second, assertion, "Two separate assertions should have been added");
diff --git a/idp-testing/src/test/java/net/shibboleth/idp/saml/saml2/profile/testing/SAML2ActionSupportTest.java b/idp-testing/src/test/java/net/shibboleth/idp/saml/saml2/profile/testing/SAML2ActionSupportTest.java
index 83ed7b4e9..715edf2ee 100644
--- a/idp-testing/src/test/java/net/shibboleth/idp/saml/saml2/profile/testing/SAML2ActionSupportTest.java
+++ b/idp-testing/src/test/java/net/shibboleth/idp/saml/saml2/profile/testing/SAML2ActionSupportTest.java
@@ -68,12 +68,12 @@ public class SAML2ActionSupportTest extends OpenSAMLInitBaseTestCase {
         Assert.assertEquals(response.getAssertions().size(), 0, "Expected zarro assertions before insert");
         Assertion assertion = SAML2ActionSupport.addAssertionToResponse(action, response,
                 relyingPartyCtx.getProfileConfig().getSecurityConfiguration(profileRequestContext).getIdGenerator(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) relyingPartyCtx.getConfiguration()).getResponderId(profileRequestContext));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) relyingPartyCtx.getConfiguration()).getResponderId(profileRequestContext));
         Assert.assertEquals(response.getAssertions().size(), 1, "Expected but one assertion after insert");
         Assert.assertTrue(response.getAssertions().contains(assertion), "Inserted assertion should be there");
         Assertion second = SAML2ActionSupport.addAssertionToResponse(action, response,
                 relyingPartyCtx.getProfileConfig().getSecurityConfiguration(profileRequestContext).getIdGenerator(),
-                ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) relyingPartyCtx.getConfiguration()).getResponderId(profileRequestContext));
+                ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) relyingPartyCtx.getConfiguration()).getResponderId(profileRequestContext));
         Assert.assertEquals(response.getAssertions().size(), 2, "Expected two assertions after two inserts");
         Assert.assertTrue(response.getAssertions().contains(assertion), "Inserted assertion should be there");
         Assert.assertNotSame(second, assertion, "Two separate assertions should have been added");

diff --git a/idp-profile-api/src/main/java/net/shibboleth/idp/profile/context/navigate/ResponderIdLookupFunction.java b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/context/navigate/ResponderIdLookupFunction.java
index 0d95b8322..d9473ad29 100644
--- a/idp-profile-api/src/main/java/net/shibboleth/idp/profile/context/navigate/ResponderIdLookupFunction.java
+++ b/idp-profile-api/src/main/java/net/shibboleth/idp/profile/context/navigate/ResponderIdLookupFunction.java
@@ -27,7 +27,7 @@ import net.shibboleth.profile.relyingparty.RelyingPartyConfiguration;
 import org.opensaml.profile.context.ProfileRequestContext;
 
 /**
  * A function that returns {@link net.shibboleth.idp.relyingparty.RelyingPartyConfiguration#getResponderId}() if
  * available from a {@link RelyingPartyContext} obtained via a lookup function, by default a child of the
  * {@link ProfileRequestContext}.
  * 
@@ -52,8 +52,8 @@ public class ResponderIdLookupFunction extends AbstractRelyingPartyLookupFunctio
                 }
                 
                 final RelyingPartyConfiguration rpConfig = rpc.getConfiguration();
-                if (rpConfig instanceof net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) {
-                    return ((net.shibboleth.idp.relyingparty.RelyingPartyConfiguration) rpConfig).getResponderId(input);
+                if (rpConfig instanceof net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) {
+                    return ((net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration) rpConfig).getResponderId(input);
                 }
             }
         }
@@ -27,7 +27,7 @@ import net.shibboleth.profile.relyingparty.RelyingPartyConfiguration;
 
 /**
- * A function that returns {@link net.shibboleth.idp.relyingparty.RelyingPartyConfiguration#getResponderId}() if
+ * A function that returns {@link net.shibboleth.idp.profile.relyingparty.RelyingPartyConfiguration#getResponderId}() if
  * available from a {@link RelyingPartyContext} obtained via a lookup function, by default a child of the
  * {@link ProfileRequestContext}.
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list